@@ -9,7 +9,8 @@ thischeck=function() {
         expect_error(species_info("Grevillea humilis subsp. maritima",verbose="yes"))
         expect_equal(species_info("Grevillea humilis subsp. maritima"),species_info(factor("Grevillea humilis subsp. maritima")))
         expect_true(all(names(species_info("Grevillea humilis subsp. maritima")) %in% c("taxonConcept","taxonName","classification","identifiers","synonyms","commonNames","childConcepts","parentConcepts","sameAsConcepts","pestStatuses","conservationStatuses","simpleProperties","images","imageIdentifier","distributionImages","screenshotImages","extantStatuses","habitats","regionTypes","references","publicationReference","identificationKeys","specimenHolding","categories","isAustralian","linkIdentifier","extantStatuses","variants")))
-        expect_warning(expect_is(species_info(guid="urn:lsid:biodiversity.org.au:apni.taxon:248651"),"list"))
+        ##this no longer throws a warning; status now: Previous APNI ID (replaced) 
+        ##expect_warning(expect_is(species_info(guid="urn:lsid:biodiversity.org.au:apni.taxon:248651"),"list"))
         expect_is(species_info(guid="bilbobaggins"),"list") ## empty result should still be a list
         expect_is(species_info("bilbobaggins"),"list") ## empty result should still be a list
         ## this one no longer matches anything with new taxonomy
